@@ -8,8 +8,8 @@ import random
 import shutil
 import queue
 
-from functions import remove_duplicate
-from colors import COLORS, RESET
+from .functions import remove_duplicate
+from .colors import COLORS, RESET
 
 
 class Checker:
